@@ -1,3 +1,5 @@
+### Encoding: UTF-8
+
 ### Name: dist.genpop
 ### Title: Genetic distances between populations
 ### Aliases: dist.genpop
@@ -10,7 +12,7 @@ data(microsatt)
 obj <- as.genpop(microsatt$tab)
 
 listDist <- lapply(1:5, function(i) quasieuclid(dist.genpop(obj,met=i)))
-for(i in 1:5) {attr(listDist[[i]],"Labels") <- obj$pop.names}
+for(i in 1:5) {attr(listDist[[i]],"Labels") <- obj@pop.names}
 listPco <- lapply(listDist, dudi.pco,scannf=FALSE)
 
 par(mfrow=c(2,3))
