@@ -1,3 +1,5 @@
+### Encoding: UTF-8
+
 ### Name: export
 ### Title: Conversion functions from adegenet to other R packages
 ### Aliases: genind2genotype genind2hierfstat
@@ -7,7 +9,7 @@
 
 if(require(hierfstat)){
 
-obj <- fstat2genind(system.file("data/diploid.dat",package="hierfstat"))
+obj <- read.fstat(system.file("data/diploid.dat",package="hierfstat"))
 
 X <- genind2hierfstat(obj)
 X
