@@ -1,3 +1,5 @@
+### Encoding: UTF-8
+
 ### Name: gstat.randtest
 ### Title: Goudet's G-statistic Monte Carlo test for genind object
 ### Aliases: gstat.randtest
@@ -8,7 +10,7 @@
 if(require(hierfstat)){
 # here the example of g.stats.glob is taken using gstat.randtest
 data(gtrunchier)
-x <- genetix2genind(X=gtrunchier[,-c(1,2)],pop=gtrunchier$Patch)
+x <- df2genind(X=gtrunchier[,-c(1,2)],pop=gtrunchier$Patch)
 
 # test in hierfstat
 gtr.test<- g.stats.glob(gtrunchier[,-1])
