@@ -1,3 +1,5 @@
+### Encoding: UTF-8
+
 ### Name: makefreq
 ### Title: Function to generate allelic frequencies
 ### Aliases: makefreq
@@ -16,8 +18,8 @@ if(require(ade4)){
 
 # perform a correspondance analysis on counts data
 
-Xcount <- genind2genpop(obj1,missing="replace")
-ca1 <- dudi.coa(as.data.frame(Xcount$tab),scannf=FALSE)
+Xcount <- genind2genpop(obj1,missing="chi2")
+ca1 <- dudi.coa(as.data.frame(Xcount@tab),scannf=FALSE)
 s.label(ca1$li,sub="Correspondance Analysis",csub=1.2)
 add.scatter.eig(ca1$eig,nf=2,xax=1,yax=2,posi="topleft")
 
