@@ -1,3 +1,5 @@
+### Encoding: UTF-8
+
 ### Name: nancycats
 ### Title: Microsatellites genotypes of 237 cats from 17 colonies of Nancy
 ###   (France)
@@ -20,7 +22,7 @@ plot(x$pop.eff,x$pop.nall,type="n",xlab="Sample size",ylab="Number of alleles")
 text(x$pop.eff,y=x$pop.nall,lab=names(x$pop.nall))
 
 par(las=3)
-barplot(table(nancycats$pop),ylab="Number of genotypes",main="Number of genotypes per colony")
+barplot(table(nancycats@pop),ylab="Number of genotypes",main="Number of genotypes per colony")
 
 # are cats structured among colonies ?
 if(require(hierfstat)){
